<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html"/>
<xsl:variable name="outputEncoding">utf-8</xsl:variable>
  <xsl:template match="TEI.2">
    <html>
     <head>
<style type="text/css">
<xsl:comment>
<xsl:value-of select="document('styles-paperprint.xml')//*"/>
</xsl:comment>
</style>
  <title><xsl:value-of select="teiHeader/fileDesc/titleStmt/title"/></title>
      </head>
      <body>

<!-- Start HTML presented front matter -->
    <xsl:apply-templates select="text/front"/>

<!--end HTML presented front matter -->

        <xsl:apply-templates select="text/body"/>
      </body>
    </html>
  </xsl:template>
  <xsl:template match="body">

    <!-- Beginning of placement for TOC -->
    
    <p style="text-align:center; font-size:15pt">Table of Contents</p>
<!-- MB 2003-03-22 Use a table so we can align the numbers and the titles correctly -->
<table border="0">
<xsl:for-each select="//div1/head">
<xsl:apply-templates  select="."  mode="showheads"/>
</xsl:for-each>
</table>
<p style="margin-bottom:3em">&#160;</p>
 <!-- Ending of placement for TOC -->

    <xsl:apply-templates select="div1"/>

<!-- MB 2003-03-21 
* This invokes the display of the footnote contents. The current placing
* means they appear as the very last thing, but that can be altered
* NB This is the sort of thing that <xsl:foreach> is really meant for.
* We gather as set of nodes (here the footnotes) and iterate over them
* i.e. do the same thing to each of them, one by one. The crucial thing
* is that our apply-templates sets the "shownotes" mode. This means
* that the nodes are handled not by the default note-handling template,
* but by the special "shownotes" one. See the actual note templates
* below for further explanation.
-->

<p style="font-size:15pt">Notes</p>
<xsl:for-each select="//note[@place='end']">
<xsl:apply-templates  select="."  mode="shownotes"/>
</xsl:for-each>

<!-- Footnote rendering invocation ends-->

<!-- Creative Commons License -->


 <!-- /Creative Commons License -->
</xsl:template>

  <!-- Divs to TOC-->
  <xsl:include href="divhandler-paper.xslt"/>

  <!-- Header and Front -->
 <xsl:include href="TEIHeader-web.xslt"/>

<!-- Xref (1) To select a bracketed URL -->

  <xsl:template match="xref[@type='url']">
   <xsl:variable name="url" select="."/>
<a href="{$url}"><xsl:apply-templates/></a>
    
    </xsl:template>

<!-- Xref (2) To take the rend attribute as the URL to be appled to bracketed text -->

  <xsl:template match="xref[@rend]">
    <xsl:variable name="hlink" select="@rend"/>

<a href="{$hlink}"><xsl:apply-templates/></a>
    
    </xsl:template>

<!-- Beginning of modified endnote handling templates -->

  <xsl:include href="endnote-handler-web.xslt"/>

  <!-- global body formatting -->
  <xsl:include href="global-body.xslt"/>
</xsl:stylesheet>
